@@ -1,7 +1,7 @@
 import json
 import pandas as pd
 from sqlalchemy import create_engine
-
+from sqlalchemy import text
 
 class mysqlUtil:
     __mysql_username = 'test'
@@ -94,7 +94,7 @@ class mysqlUtil:
             sql ='select id,url,fdesc,fsize,duration,ftype,uptime,pid from sftp_files where ftype="{}" order by uptime desc limit 100'.format(
                 ftype)
         connection = self.engine.connect()
-        df = pd.read_sql(sql, con=connection)
+        df = pd.read_sql(text(sql), con=connection)
         results = json.loads(df.to_json(orient='records'))
         if results and len(results) == 1:
             return results[0]
@@ -114,7 +114,7 @@ class mysqlUtil:
             sql ='select id,url,fdesc,fsize,duration,ftype,uptime,pid from sftp_files where pid="{}" order by uptime desc limit 100'.format(
                 pid)
         connection = self.engine.connect()
-        df = pd.read_sql(sql=sql,con=connection)
+        df = pd.read_sql(sql=text(sql),con=connection)
         results = json.loads(df.to_json(orient='records'))
         if results and len(results) == 1:
             return results[0]
